@@ -2,7 +2,7 @@ CREATE TABLE "inbox" (
 	"id" serial,
 	"number" character varying(20) NOT NULL,
 	"smsdate" timestamp NOT NULL,
-	"insertdate" timestamp DEFAULT 'now' NOT NULL,
+	"insertdate" timestamp DEFAULT now() NOT NULL,
 	"text" character varying(160),
 	"phone" integer,
 	"processed" bool DEFAULT 'false',
@@ -12,8 +12,8 @@ CREATE TABLE "inbox" (
 CREATE TABLE "outbox" (
 	"id" serial,
 	"number" character varying(20) NOT NULL,
-	"processed_date" timestamp DEFAULT 'now' NOT NULL,
-	"insertdate" timestamp DEFAULT 'now' NOT NULL,
+	"processed_date" timestamp DEFAULT now() NOT NULL,
+	"insertdate" timestamp DEFAULT now() NOT NULL,
 	"text" character varying(160),
 	"phone" integer,
 	"processed" bool DEFAULT 'false',
